==> unit-1.0.49-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableOwnerItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableOwnerItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _19_53_0393878755 _19_53_0393878755;
	public TasksTableOwnerItem._19_53_0393878755. Owner owner;

    public TasksTableOwnerItem(UnitBox box) {
        super(box);
        id("a259308081");
    }

    @Override
	public void init() {
		super.init();
		if (_19_53_0393878755 == null) _19_53_0393878755 = register(new _19_53_0393878755(box()).<_19_53_0393878755>id("a869443126").owner(TasksTableOwnerItem.this));
		if (_19_53_0393878755 != null) owner = _19_53_0393878755.owner;
	}

	public class _19_53_0393878755 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableOwnerItem._19_53_0393878755. Owner owner;

		public _19_53_0393878755(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (owner == null) owner = register(new Owner(box()).<Owner>id("a1384135352").owner(TasksTableOwnerItem.this));
		}

		public class Owner extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Owner(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableOwnerItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableOwnerItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _19_53_0393878755 _19_53_0393878755;
	public TasksTableOwnerItem._19_53_0393878755. Owner owner;

    public TasksTableOwnerItem(UnitBox box) {
        super(box);
        id("a259308081");
    }

    @Override
	public void init() {
		super.init();
		if (_19_53_0393878755 == null) _19_53_0393878755 = register(new _19_53_0393878755(box()).<_19_53_0393878755>id("a869443126").owner(TasksTableOwnerItem.this));
		if (_19_53_0393878755 != null) owner = _19_53_0393878755.owner;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_19_53_0393878755 != null) _19_53_0393878755.unregister();
	}

	public class _19_53_0393878755 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableOwnerItem._19_53_0393878755. Owner owner;

		public _19_53_0393878755(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (owner == null) owner = register(new Owner(box()).<Owner>id("a1384135352").owner(TasksTableOwnerItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (owner != null) owner.unregister();
		}

		public class Owner extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Owner(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
